pub fn required_server_signatures_to_verify_event(
object: &CanonicalJsonObject,
rules: &SignaturesRules,
) -> Result<BTreeSet<OwnedServerName>, VerificationError>Expand description
Get the list of servers whose signature must be checked to verify the given event.
Applies the rules for validating signatures on received events for populating the list:
- Add the server of the
sender, except if it’s an invite event that results from a third-party invite. - For room versions 1 and 2, add the server of the
event_id. - For room versions that support restricted join rules, if it’s a join event with a
join_authorised_via_users_server, add the server of that user.